//
// C++ Implementation: kpgfunction
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgfunction.h"

#include <qlineedit.h>
#include <qtable.h>

// include files for KDE
#include <kdebug.h>
#include <kmessagebox.h>
#include <klocale.h>
#include <ktextedit.h>

#include "kpgdatabase.h"
#include "../kpglinklabel.h"
#include "kpgfunctionsfolder.h"
#include "../PropertyPages/kpgfunctionproppage.h"
#include "../kpgsqldialog.h"


KPGFunction::KPGFunction(KPGFunctionsFolder *parent, const QString name, pqxx::oid _oid)
 : KPGObject(parent, name, _oid)
{
	setPixmap(0, *m_pIconFunction);
}

KPGFunction::KPGFunction(KPGFunctionsFolder *parent, KPGFunction *after, const QString name, pqxx::oid _oid)
 : KPGObject(parent, after, name, _oid)
{
	setPixmap(0, *m_pIconFunction);
}


KPGFunction::~KPGFunction()
{
}

void KPGFunction::setProperties(
		const QString strDescription,
		bool bIsAgg,
		bool bIsSecdef,
		bool bIsStrict,
		bool bRetSet,
		const QString strVolatile,
		int iNArgs,
		const QString strBin,
		const QString strACL,
		const QString strReturnTypName,
		pqxx::oid oidReturnType,
		const QString strLanName,
		const QString strFuncOwner
	)
{
	m_strDescription = strDescription;
	m_bIsAgg = bIsAgg;
	m_bIsSecdef = bIsSecdef;
	m_bIsStrict = bIsStrict;
	m_bRetSet = bRetSet;
	m_strVolatile = strVolatile;
	m_iNArgs = iNArgs;
	m_strBin = strBin;
	m_strACL = strACL;
	m_strReturnTypName = strReturnTypName;
	m_oidReturnType = oidReturnType;
	m_strLanName = strLanName;
	m_strFuncOwner = strFuncOwner;
	
	//--- Set icon for function type
	if(strLanName == "c")
		setPixmap(0, *m_pIconFunctionC);
	else
		if(strLanName == "sql")
			setPixmap(0, *m_pIconFunctionSql);
		else
			if(strLanName == "plpgsql")
				setPixmap(0, *m_pIconFunctionPl);
}

void KPGFunction::displayProperties(QWidget *widgetProperies)
{
	if(widgetProperies == 0) return; // be defensive, user may close Properties window
		
	// Display function info
	KPGFunctionPropPage *pPropertyPage = static_cast <KPGFunctionPropPage *> (widgetProperies);
	
	//---------------------------------------------------------------------------
	// Display properties
	QTable *pTableProperties = pPropertyPage->m_pTableProperties;
	
	//--- Header
	// field names
  QHeader* hHeader = pTableProperties->horizontalHeader();

  hHeader->setLabel(0, i18n("Name"));
	hHeader->setLabel(1, i18n("Value"));
	hHeader->setLabel(2, i18n("Description"));
	
	int iRow = 0;
  	
	//--- OID
	pTableProperties->setText(iRow, 0, i18n("OID"));
  pTableProperties->setText(iRow, 1, QString("%1").arg(m_oid));
	pTableProperties->setText(iRow++, 2, i18n("PostgreSQL row identifier"));
	
	//--- Name
	pTableProperties->setText(iRow, 0, i18n("Name"));
  pTableProperties->setText(iRow, 1, text(0));
	pTableProperties->setText(iRow++, 2, i18n("Function name"));
	
	//--- Description
	pTableProperties->setText(iRow, 0, i18n("Description"));
  pTableProperties->setText(iRow, 1, m_strDescription);
	pTableProperties->setText(iRow++, 2, i18n("Description of the function"));
		
	//--- Is Aggregate
	pTableProperties->setText(iRow, 0, i18n("Is Aggregate"));
  pTableProperties->setText(iRow, 1, (m_bIsAgg) ? i18n("True") : i18n("False"));
	pTableProperties->setText(iRow++, 2, i18n("True if function is an aggregate function)"));
	
	//--- Is Security definer
	pTableProperties->setText(iRow, 0, i18n("Is Security definer"));
  pTableProperties->setText(iRow, 1, (m_bIsSecdef) ? i18n("True") : i18n("False"));
	pTableProperties->setText(iRow++, 2, i18n("Function is a security definer (i.e., a \"setuid\" function"));
			
	//--- Is Strict
	pTableProperties->setText(iRow, 0, i18n("Is Strict"));
  pTableProperties->setText(iRow, 1, (m_bIsStrict) ? i18n("True") : i18n("False"));
	pTableProperties->setText(iRow++, 2, i18n("Function returns null if any call argument is null. In that case the function won't actually be called at all. Functions that are not \"strict\" must be prepared to handle null inputs."));
	
	//--- Return Set
	pTableProperties->setText(iRow, 0, i18n("Return Set"));
  pTableProperties->setText(iRow, 1, (m_bRetSet) ? i18n("True") : i18n("False"));
	pTableProperties->setText(iRow++, 2, i18n("Function returns a set (i.e., multiple values of the specified data type)"));
	
	//--- Volatile
	pTableProperties->setText(iRow, 0, i18n("Volatile"));
  pTableProperties->setText(iRow, 1, m_strVolatile);
	pTableProperties->setText(iRow++, 2, i18n("Tells whether the function's result depends only on its input arguments, or is affected by outside factors. It is i for \"immutable\" functions, which always deliver the same result for the same inputs. It is s for \"stable\" functions, whose results (for fixed inputs) do not change within a scan. It is v for \"volatile\" functions, whose results may change at any time. (Use v also for functions with side-effects, so that calls to them cannot get optimized away.) "));
	
	//--- Number of argument
	pTableProperties->setText(iRow, 0, i18n("Number of arguments"));
  pTableProperties->setText(iRow, 1, QString("%1").arg(m_iNArgs));
	pTableProperties->setText(iRow++, 2, i18n("Number of arguments"));
	
	//--- Bin
	pTableProperties->setText(iRow, 0, i18n("Bin"));
  pTableProperties->setText(iRow, 1, m_strBin);
	pTableProperties->setText(iRow++, 2, i18n("Additional information about how to invoke the function. Again, the interpretation is language-specific."));
	
	//--- Access privileges
	pPropertyPage->setACL(m_strACL);
	
	//--- Type name
	pTableProperties->setText(iRow, 0, i18n("Type name"));
  KPGLinkLabel *pLabel = new KPGLinkLabel( pTableProperties, "Type name" );
	pLabel->setValues(m_oidReturnType, m_strReturnTypName);
	pTableProperties->setCellWidget(iRow, 1, pLabel);
	pTableProperties->setText(iRow++, 2, i18n("Return data type name"));
	
	//--- Language name
	pTableProperties->setText(iRow, 0, i18n("Language name"));
  pTableProperties->setText(iRow, 1, m_strLanName);
	pTableProperties->setText(iRow++, 2, i18n("Name of the language (to be specified when creating a function)"));
	
	//--- Owner
	pTableProperties->setText(iRow, 0, i18n("Owner"));
  pTableProperties->setText(iRow, 1, m_strFuncOwner);
	pTableProperties->setText(iRow++, 2, i18n("Function owner"));
	
	//--- Namespace
	/*pTableProperties->setText(iRow, 0, i18n("Namespace"));
  pTableProperties->setText(iRow, 1, m_strNameSpace);
	pTableProperties->setText(iRow++, 2, i18n("Name of the namespace"));
	*/
	
	for(int nCol = 0; nCol < 3; nCol++)
  {
    pTableProperties->adjustColumn(nCol);
  }
	
	pPropertyPage->m_pLineEditArgTypes->setText(m_strArgTypes);
	pPropertyPage->m_pTextEditSource->setText(m_strSrc);
}

// Refresh only function info, without childs objects
bool KPGFunction::refreshItem()
{
	// Get pointer to server for version info
	KPGDatabase *pDatabase = static_cast <KPGDatabase *> (parent()->parent()->parent());
	
	work pqxxXaction(* pDatabase->connection(), "refreshItem"); 
	
	// obtain function info
	QString strQuery("SELECT pr.oid, pr.proname, description, pr.proisagg, pr.prosecdef, pr.proisstrict, proretset, pr.provolatile, pr.pronargs, pr.probin, pr.proacl, prorettype, typ.typname, lanname, pg_get_userbyid(proowner) as funcowner  ");
	strQuery.append("FROM pg_proc pr ");
	strQuery.append("JOIN pg_type typ ON typ.oid=prorettype ");
	strQuery.append("JOIN pg_language LNG ON LNG.oid=prolang ");
	strQuery.append("LEFT OUTER JOIN pg_description des ON des.objoid=pr.oid ");
	
	strQuery.append("WHERE pr.oid = " + QString("%1").arg(m_oid));
		
	try
	{
		pqxx::result pqxxResultFunctions = pqxxXaction.Exec(strQuery.latin1());
	
		if(pqxxResultFunctions.size() != 1)
		{
		kdDebug() << "KPGFunction::refreshItem(): expect one row in result" << endl;
		return false;
		}
				
		bool bIsAgg;
		bool bIsSecdef;
		bool bIsStrict;
		bool bRetSet;
		int iNArgs;
		pqxx::oid oidReturnType = 0;
	
		pqxxResultFunctions[0]["proisagg"].to(bIsAgg);
		pqxxResultFunctions[0]["prosecdef"].to(bIsSecdef);
		pqxxResultFunctions[0]["proisstrict"].to(bIsStrict);
		pqxxResultFunctions[0]["proretset"].to(bRetSet);
		pqxxResultFunctions[0]["pronargs"].to(iNArgs);
		pqxxResultFunctions[0]["prorettype"].to(oidReturnType);
				
		setProperties(
		pqxxResultFunctions[0]["description"].c_str(), 
		bIsAgg,
		bIsSecdef,
		bIsStrict,
		bRetSet,
		pqxxResultFunctions[0]["provolatile"].c_str(), 
		iNArgs,
		pqxxResultFunctions[0]["probin"].c_str(), 
		pqxxResultFunctions[0]["proacl"].c_str(), 
		pqxxResultFunctions[0]["typname"].c_str(),
		oidReturnType,
		pqxxResultFunctions[0]["lanname"].c_str(), 
		pqxxResultFunctions[0]["funcowner"].c_str()
		);
		
		//-- Get function source and arguments
		strQuery = QString("SELECT oidvectortypes(proargtypes) AS arguments, prosrc FROM pg_proc WHERE oid=%1;").arg(m_oid);
		pqxx::result pqxxResultSource = pqxxXaction.exec(strQuery.latin1());
		
		if (pqxxResultSource.size() > 0)
		{ 
			setArgTypes(pqxxResultSource[0][0].c_str());
			setSrc(pqxxResultSource[0][1].c_str());
		}  
	
	}
	catch (const std::exception &e)
	{
		kdError() << e.what() << endl;
		KPGSqlDialog dlg(0, strQuery, e.what());
		dlg.exec();
		return false;
	} 
	
	return true;
}

