//
// C++ Implementation: kpgpropertypagechildview
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpgpropertypagechildview.h"

#include <qlayout.h>

#include <kiconloader.h>

#include "kpogreview.h"

// Database objects includes
#include "DbObjects/kpgserver.h"
#include "DbObjects/kpgdatabase.h"
#include "DbObjects/kpgschema.h"
#include "DbObjects/kpgview.h"
#include "DbObjects/kpgtable.h"
#include "DbObjects/kpgsequence.h"
#include "DbObjects/kpgfunction.h"
#include "DbObjects/kpgprimarykey.h"
#include "DbObjects/kpgindex.h"
#include "DbObjects/kpglanguage.h"

// Property pages includes
#include "PropertyPages/kpgvoidproppage.h"
#include "PropertyPages/kpgpropertypage.h"
#include "PropertyPages/kpgserverproppage.h"
#include "PropertyPages/kpgtablespaceproppage.h"
#include "PropertyPages/kpgdatabaseproppage.h"
#include "PropertyPages/kpgschemaproppage.h"
#include "PropertyPages/kpgtableproppage.h"
#include "PropertyPages/kpgviewproppage.h"
#include "PropertyPages/kpgtablecolumnproppage.h"
#include "PropertyPages/kpgprimarykeyconstrproppage.h"
#include "PropertyPages/kpgforeignkeyconstrproppage.h"
#include "PropertyPages/kpgcheckconstrproppage.h"
#include "PropertyPages/kpguniqueconstrproppage.h"
#include "PropertyPages/kpgprimarykeyproppage.h"
#include "PropertyPages/kpgindexproppage.h"
#include "PropertyPages/kpgruleproppage.h"
#include "PropertyPages/kpgtriggerproppage.h"
#include "PropertyPages/kpgfunctionproppage.h"
#include "PropertyPages/kpgsequenceproppage.h"
#include "PropertyPages/kpgoperatorproppage.h"
#include "PropertyPages/kpgoperatorclassproppage.h"
#include "PropertyPages/kpgaggregateproppage.h"
#include "PropertyPages/kpguserproppage.h"
#include "PropertyPages/kpggroupproppage.h"
#include "PropertyPages/kpgtypeproppage.h"
#include "PropertyPages/kpglanguageproppage.h"
#include "PropertyPages/kpgdomainproppage.h"
#include "PropertyPages/kpgconversionproppage.h"
#include "PropertyPages/kpgcastproppage.h"
#include "PropertyPages/kpgdomainconstrproppage.h"

KPGPropertyPageChildView::KPGPropertyPageChildView(KPoGreView *pPoGreView)
 : KMdiChildView(i18n("Properties"), pPoGreView, "KPGPropertyPageChildView")
{
	m_pPoGreView = pPoGreView;
	m_pWidgetProperties = 0;
	m_pLayout = new QHBoxLayout(this, 0, -1, "layout" );
	
	setIcon( SmallIcon("history") );
}


KPGPropertyPageChildView::~KPGPropertyPageChildView()
{
	destroyPropertiesWidget();
}

// Destroy Properties widget
void KPGPropertyPageChildView::destroyPropertiesWidget()
{
  // delete old widget property page
  if(m_pWidgetProperties)
  {
    	// disconnect all
		disconnect(m_pWidgetProperties, 0, 0, 0);
		m_pWidgetProperties->close(true);
		m_pWidgetProperties = 0;
  }
  
}

// Create Properties widget, with regards to selected type in tree
QWidget* KPGPropertyPageChildView::createPropertiesWidget(KPGTreeItem * pItem)
{
	destroyPropertiesWidget();
	
	if(pItem == 0)
		return 0;
	
  	// create new property page
  	switch(pItem->type())
    {
		//******************************************************************************************
		//
		// Main objects
		//
		//******************************************************************************************
				
        case KPGTreeItem::nodeServer:
          m_pWidgetProperties = new KPGServerPropPage(this, static_cast <KPGServer *> (pItem));  
          break;

        case KPGTreeItem::nodeDatabase:
          m_pWidgetProperties = new KPGDatabasePropPage(this, static_cast <KPGDatabase *> (pItem));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break;
        				
				case KPGTreeItem::nodeSchema:
          m_pWidgetProperties = new KPGSchemaPropPage(this, static_cast <KPGSchema *> (pItem));
					
          connect(m_pWidgetProperties, SIGNAL(sigCurrentTabChanged(KPGSchemaPropPage *, QWidget *)), m_pPoGreView, SLOT(slotSchemaPropTabChanged(KPGSchemaPropPage *, QWidget *)));
          
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          
          break;
				
		case KPGTreeItem::nodeFolderGroups:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
				
				case KPGTreeItem::nodeFolderUsers:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
					
				case KPGTreeItem::nodeFolderTablespaces:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
				
				case KPGTreeItem::nodeUser:
          m_pWidgetProperties = new KPGUserPropPage(this);
          break;
					
				case KPGTreeItem::nodeGroup:
          m_pWidgetProperties = new KPGGroupPropPage(this);
          break;
					
				case KPGTreeItem::nodeTablespace:
          m_pWidgetProperties = new KPGTablespacePropPage(this, pItem->text(0));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break;
									
			//******************************************************************************************
			//
			// Database objects folders
			//
			//******************************************************************************************
										
			case KPGTreeItem::nodeFolderTables:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
				
				case KPGTreeItem::nodeFolderViews:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderSequences:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderFunctions:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderOperators:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderOperatorClasses:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderAggregates:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
											
				case KPGTreeItem::nodeFolderTypes:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderLanguages: 
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderDomains:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderConversions:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;
					
				case KPGTreeItem::nodeFolderCasts:
          m_pWidgetProperties = new KPGPropertyPage(this);
          break;		
				
				
			//******************************************************************************************
			//
			// Database objects
			//
			//******************************************************************************************
				
				case KPGTreeItem::nodeTable:
          m_pWidgetProperties = new KPGTablePropPage(this, static_cast <KPGTable *> (pItem));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break;

        case KPGTreeItem::nodeView:
          m_pWidgetProperties = new KPGViewPropPage(this, static_cast <KPGView *> (pItem));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break;
					
				case KPGTreeItem::nodeSequence:
          m_pWidgetProperties = new KPGSequencePropPage(this, static_cast <KPGSequence *> (pItem));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break;
					
				case KPGTreeItem::nodeFunction:
          m_pWidgetProperties = new KPGFunctionPropPage(this, static_cast <KPGFunction *> (pItem));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break;
					
				case KPGTreeItem::nodeOperator:
          m_pWidgetProperties = new KPGOperatorPropPage(this);
          break;
				
				case KPGTreeItem::nodeOperatorClass:
          m_pWidgetProperties = new KPGOperatorClassPropPage(this);
          break;
					
				case KPGTreeItem::nodeAggregate:
          m_pWidgetProperties = new KPGAggregatePropPage(this);
          break;
				
				case KPGTreeItem::nodeType:
					m_pWidgetProperties = new KPGTypePropPage( this);
          break;
				
				case KPGTreeItem::nodeLanguage:
					m_pWidgetProperties = new KPGLanguagePropPage( this, static_cast <KPGLanguage *> (pItem));
          connect(m_pWidgetProperties, SIGNAL(sigRunWizard(const QString &)), m_pPoGreView, SLOT( slotRunWizard(const QString &))); 
          break; 
				
				case KPGTreeItem::nodeDomain:
					m_pWidgetProperties = new KPGDomainPropPage( this);
          break; 
				
				case KPGTreeItem::nodeConversion:
					m_pWidgetProperties = new KPGConversionPropPage( this);
          break; 
				
				case KPGTreeItem::nodeCast:
					m_pWidgetProperties = new KPGCastPropPage( this);
          break;			
					
				//******************************************************************************************
				//
				// Table objects folders
				//
				//******************************************************************************************
				
						
				case KPGTreeItem::nodeFolderTableColumns:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
					
				case KPGTreeItem::nodeFolderTableConstraints:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
					
				case KPGTreeItem::nodeFolderTableIndexes:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
					
				case KPGTreeItem::nodeFolderRules:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
					
				case KPGTreeItem::nodeFolderTriggers:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
        
        // Domain objects folders
            
        case KPGTreeItem::nodeFolderDomainConstraints:
          m_pWidgetProperties = new KPGPropertyPage( this);
          break;
					
				//******************************************************************************************
				//
				// Table objects
				//
				//******************************************************************************************
									
				case KPGTreeItem::nodeTableColumn:
          m_pWidgetProperties = new KPGTableColumnPropPage( this);
          break;
					
				case KPGTreeItem::nodePrimaryKeyConstr:
          m_pWidgetProperties = new KPGPrimaryKeyConstrPropPage( this);
          break;
					
				case KPGTreeItem::nodeForeignKeyConstr:
          m_pWidgetProperties = new KPGForeignKeyConstrPropPage( this);
          break;
					
				case KPGTreeItem::nodeUniqueConstr:
          m_pWidgetProperties = new KPGUniqueConstrPropPage( this);
          break;
					
				case KPGTreeItem::nodeCheckConstr:
          m_pWidgetProperties = new KPGCheckConstrPropPage( this);
          break;
					
				case KPGTreeItem::nodePrimaryKey:
          m_pWidgetProperties = new KPGPrimaryKeyPropPage( this, static_cast <KPGPrimaryKey *> (pItem));
          break;
					
				case KPGTreeItem::nodeIndex:
          m_pWidgetProperties = new KPGIndexPropPage( this, static_cast <KPGIndex *> (pItem));
          break;
					
				case KPGTreeItem::nodeRule:
          m_pWidgetProperties = new KPGRulePropPage( this);
          break;
					
				case KPGTreeItem::nodeTrigger:
          m_pWidgetProperties = new KPGTriggerPropPage( this);
          break;
          
        // Domain object
        case KPGTreeItem::nodeDomainConstr:
          m_pWidgetProperties = new KPGDomainConstrPropPage( this);
          break;
					
		//******************************************************************************************
		//
		// Unselected or unknown
		//
		//******************************************************************************************
					

        case KPGTreeItem::nodeUnselected:
          break;
					
		  default:
				m_pWidgetProperties = new KPGVoidPropPage(this);
          break;
      } 
  
  if(m_pWidgetProperties)
    { 
      //this->setCurrentPage(0);
      m_pLayout->addWidget( m_pWidgetProperties );
      m_pWidgetProperties->show();
			
      connect(m_pWidgetProperties, SIGNAL(sigSearchObject(const pqxx::oid)), m_pPoGreView, SLOT( slotSearchObject(const pqxx::oid)));
    }

	return m_pWidgetProperties;
}

bool KPGPropertyPageChildView::requestClose()
{
	if(KMessageBox::questionYesNo(this, i18n("Really close property window ?"), "KPoGre") == KMessageBox::Yes) 
	{
		return true;
	}
	return false;
}

