//
// C++ Implementation: kpogrecontroller
//
// Description: 
//
//
// Author: Lumir Vanek <lvanek@users.sourceforge.net>, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "kpogrecontroller.h"

// include files for Qt
#include <qprinter.h>
#include <qinputdialog.h>

// include files for KDE
#include <kactioncollection.h>
#include <kiconloader.h>
#include <kfiledialog.h>
#include <kcursor.h>
#include <kdebug.h>
#include <kstatusbar.h>

// application specific includes
#include "kpogrecomboaction.h"
#include "kpgsearchdialog.h"
#include "kpgbookmarksbutton.h"
#include "kpgsqlqueryresultchildview.h"

// Database objects includes
#include "DbObjects/kpgserver.h"
#include "DbObjects/kpgfunction.h"
#include "DbObjects/kpgtablespace.h"
#include "DbObjects/kpgdatabase.h"
#include "DbObjects/kpgschema.h"
#include "DbObjects/kpgtrigger.h"
#include "DbObjects/kpgdomain.h"
#include "DbObjects/kpgtable.h"
#include "DbObjects/kpgtablecolumn.h"
#include "DbObjects/kpgtableindex.h"

KPoGreController::KPoGreController(KPoGreView *ownerView)
 : QObject()
{
	view = ownerView;
	m_pDlgSearch = 0;
}


KPoGreController::~KPoGreController()
{
	if(m_pDlgSearch)
		delete m_pDlgSearch; 
}

void KPoGreController::initActions(KActionCollection * pAactionCollection)
{
  	//-----------------------------------------------------------------
	// Database menu       
	m_pActDatabaseConnect = new KAction(i18n("&Connect..."), "connect_established", 0, this, SLOT(slotDatabaseConnect()), pAactionCollection, "connect");
	m_pActDatabaseDisconnect = new KAction(i18n("&Disconnect"), "connect_no", 0, this, SLOT(slotDatabaseDisconnect()), pAactionCollection, "disconnect");
	
	m_pActDatabaseRunQuery = new KAction(i18n("&Run query"), "fork", Key_F8, this, SLOT(slotDatabaseRunQuery()), 
	pAactionCollection, "run_query");
	m_pActDatabaseStopQuery = new KAction(i18n("&Stop query"), "stop", 0, this, SLOT(slotDatabaseStopQuery()), pAactionCollection, "stop_query");
	
	m_pActDatabaseFetchNext = new KAction(i18n("Fetch &next"), "1downarrow", 0, this, SLOT(slotDatabaseFetchNext()), pAactionCollection, "fetch_next");
	m_pActDatabaseFetchAll = new KAction(i18n("Fetch &all"), "2downarrow", 0, this, SLOT(slotDatabaseFetchAll()), pAactionCollection, "fetch_all");
	
	m_pActDatabaseWizard = new KAction(i18n("&Wizard..."), "wizard", Key_F9, this, SLOT(slotDatabaseWizard()), pAactionCollection, "wizard");
		
		
	//-----------------------------------------------------------------
	// Datatable menu       
	
  	(void) new KAction(i18n("Reload data from database"), "reload", 0, this, SLOT(slotTableRefreshData()), pAactionCollection, "refresh_data");
  		
  		
  	(void) new KAction(i18n("First row"), "player_start", 0, this, SLOT(slotTableFirstRow()), pAactionCollection, "table_first_row");
  	
	(void) new KAction(i18n("Previous row"), "1leftarrow", 0, this, SLOT(slotTablePreviousRow()), pAactionCollection, "table_previous_row");
	
	(void) new KAction(i18n("Next row"), "1rightarrow", 0, this, SLOT(slotTableNextRow()), pAactionCollection, "table_next_row");
	
	(void) new KAction(i18n("Last row"), "player_end", 0, this, SLOT(slotTableLastRow()), pAactionCollection, "table_last_row");
	
	(void) new KAction(i18n("Edit cell"), "edittool", Key_F2, this, SLOT(slotTableEditCell()), pAactionCollection, "table_edit_cell");
	
	(void) new KAction(i18n("Clear cell"), "deletecell", 0, this, SLOT(slotTableClearCell()), pAactionCollection, "table_clear_cell");
	
	(void) new KAction(i18n("Insert row"), "insert_table_row", 0, this, SLOT(slotTableInsertRow()), pAactionCollection, "table_insert_row");
	
	(void) new KAction(i18n("Delete row"), "delete_table_row", 0, this, SLOT(slotTableDeleteRow()), pAactionCollection, "table_delete_row");
	
	(void) new KAction(i18n("Update changes"), "ok", 0, this, SLOT(slotTableCommitChanges()), pAactionCollection, "table_commit_changes");
	
	(void) new KAction(i18n("Cancel changes"), "cancel", 0, this, SLOT(slotTableCancelChanges()), pAactionCollection, "table_cancel_changes");
	
  		
	//-----------------------------------------------------------------
	// File menu
	m_pActFileExportResult = new KAction(i18n("&Export Result..."), "fileexport", 0, this, SLOT(slotExportResult()), pAactionCollection, "export_result");
	
	m_pActFileNewWindow = new KAction(i18n("New &Window"), 0, 0, this, SLOT(slotFileNewWindow()), pAactionCollection,"file_new_window");
	m_pActFileNew = KStdAction::openNew(this, SLOT(slotFileNew()), pAactionCollection);
	m_pActFileOpen = KStdAction::open(this, SLOT(slotFileOpen()), pAactionCollection);
	m_pActFileOpenRecent = KStdAction::openRecent(this, SLOT(slotFileOpenRecent(const KURL&)), pAactionCollection);
	m_pActFileSave = KStdAction::save(this, SLOT(slotFileSave()), pAactionCollection);
	m_pActFileSaveAs = KStdAction::saveAs(this, SLOT(slotFileSaveAs()), pAactionCollection);
	m_pActFileClose = KStdAction::close(this, SLOT(slotFileClose()), pAactionCollection);
	m_pActFilePrint = KStdAction::print(this, SLOT(slotFilePrint()), pAactionCollection);
	m_pActFileQuit = KStdAction::quit(this, SLOT(slotFileQuit()), pAactionCollection);
	
	m_pActFileNewWindow->setStatusText(i18n("Opens a new application window"));
	m_pActFileNew->setStatusText(i18n("Creates a new document"));
	m_pActFileOpen->setStatusText(i18n("Opens an existing document"));
	m_pActFileOpenRecent->setStatusText(i18n("Opens a recently used file"));
	m_pActFileSave->setStatusText(i18n("Saves the actual document"));
	m_pActFileSaveAs->setStatusText(i18n("Saves the actual document as..."));
	m_pActFileClose->setStatusText(i18n("Closes the actual document"));
	m_pActFilePrint ->setStatusText(i18n("Prints out the actual document"));
	m_pActFileQuit->setStatusText(i18n("Quits the application"));
	
	//-----------------------------------------------------------------
	// Edit menu
	m_pActEditUndo = KStdAction::undo(this, SLOT(slotEditUndo()), pAactionCollection,"undo");
	m_pActEditRedo = KStdAction::redo(this, SLOT(slotEditRedo()), pAactionCollection,"redo");
									
	m_pActEditCut = KStdAction::cut(this, SLOT(slotEditCut()), pAactionCollection);
	m_pActEditCopy = KStdAction::copy(this, SLOT(slotEditCopy()), pAactionCollection);
	m_pActEditPaste = new KPasteTextAction(i18n("&Paste"), "editpaste", CTRL+Key_P, this, SLOT(slotEditPaste()), pAactionCollection, "edit_paste");
		
	m_pActEditFind = KStdAction::find( this, SLOT(slotEditFind()), pAactionCollection, "find" );
	m_pActEditFindNext = KStdAction::findNext( this, SLOT(slotEditFindNext()), pAactionCollection, "findNext" );
											
	
	m_pActEditClearInputArea = new KAction(i18n("Clear &Inputarea"), "editdelete", 0, this, SLOT(slotEditClearInputArea()), pAactionCollection, "clear_input_area");
	
		
	m_pActEditDeselect = new KAction( i18n("D&eselect Node"), CTRL+Key_E, this,
										SLOT(slotEditDeselect()), pAactionCollection, "deselect" );

  	//-----------------------------------------------------------------
	// View menu
  	m_pActViewNodeUp = new KAction( i18n("To &Parent Item"), "up", 0, this,
	                                SLOT(slotViewNodeUp()), pAactionCollection, "treeitem_up" );
																	
	m_pActViewNodeBack = new KAction( i18n("To &Back Item"), "back", 0, this,
	                                SLOT(slotViewNodeBack()), pAactionCollection, "treeitem_back" );
																	
	m_pActViewNodeForward = new KAction( i18n("To &Forward Item"), "forward", 0, this,
	                                SLOT(slotViewNodeForward()), pAactionCollection, "treeitem_forward" );
																	
	m_pActViewToolBar = KStdAction::showToolbar(this, SLOT(slotViewToolBar()), pAactionCollection, "showtoolbar");
  m_pActViewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), pAactionCollection, "showstatusbar");
 
  	//-----------------------------------------------------------------
	// Settings menu
	KStdAction::keyBindings(view, SLOT(slotConfigureKeys()), pAactionCollection, "configurekeys");
  	KStdAction::configureToolbars(view, SLOT(slotConfigToolbars()), pAactionCollection, "configuretoolbars");
	KStdAction::preferences(view, SLOT(slotConfigure()), pAactionCollection, "configure");
	
  	//-----------------------------------------------------------------
	//-----------------------------------------------------------------
	// Popup menus
  	//-----------------------------------------------------------------
  	//-----------------------------------------------------------------
  
	m_pActFolderRefresh = new KAction( i18n("&Refresh"), "reload", Key_F5, this, SLOT(slotRefresh()), pAactionCollection, "refresh" );
	
	//--- Database related menu actions
	
	(void) new KAction( i18n("&Create database..."), "wizard", 0, this, SLOT(slotCreateDatabase()), pAactionCollection, "create_database" );
	
	(void) new KAction( i18n("&Drop database..."), "editdelete", 0, this, SLOT(slotDropDatabase()), pAactionCollection, "drop_database" );
 
  (void) new KAction( i18n("&Analyze..."), 0, 0, this, SLOT(slotAnalyseDatabase()), pAactionCollection, "analyse_database" );

  (void) new KAction( i18n("Re&index..."), 0, 0, this, SLOT(slotReindexDatabase()), pAactionCollection, "reindex_database" );
    
  (void) new KAction( i18n("Set &owner..."), 0, 0, this, SLOT(slotSetOwnerDatabase()), pAactionCollection, "set_owner_database" );
  
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesDatabase()), pAactionCollection, "grant_privileges_database" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesDatabase()), pAactionCollection, "revoke_privileges_database" );
  
  (void) new KAction( i18n("Dump..."), 0, 0, this, SLOT(slotDumpDatabase()), pAactionCollection, "dump_database" );
  
  (void) new KAction( i18n("Restore..."), 0, 0, this, SLOT(slotRestoreDatabase()), pAactionCollection, "restore_database" );
    
  (void) new KAction( i18n("Disconnect from database"), "connect_no", 0, this, SLOT(slotDisconnectDatabase()), pAactionCollection, "disconnect_database" );
   
	
	//--- Schema related menu actions
	
	(void) new KAction( i18n("&Create schema..."), "wizard", 0, this, SLOT(slotCreateSchema()), pAactionCollection, "create_schema" );
	
	(void) new KAction( i18n("&Drop schema..."), "editdelete", 0, this, SLOT(slotDropSchema()), pAactionCollection, "drop_schema" );
	
	(void) new KAction( i18n("R&ename schema..."), "edittool", 0, this, SLOT(slotModifySchema()), pAactionCollection, "rename_schema" );
  
  (void) new KAction( i18n("Set &owner..."), 0, 0, this, SLOT(slotSetOwnerSchema()), pAactionCollection, "set_owner_schema" );
	
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesSchema()), pAactionCollection, "grant_privileges_schema" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesSchema()), pAactionCollection, "revoke_privileges_schema" );
  
	//--- Table related menu actions
	
	(void) new KAction( i18n("&Create table..."), "wizard", 0, this, SLOT(slotCreateTable()), pAactionCollection, "create_table" );
	
	(void) new KAction( i18n("&Drop table..."), "editdelete", 0, this, SLOT(slotDropTable()), pAactionCollection, "drop_table" );
	
  (void) new KAction( i18n("R&ename table..."), "edittool", 0, this, SLOT(slotRenameTable()), pAactionCollection, "rename_table" );
    
  (void) new KAction( i18n("&Analyze table..."), 0, 0, this, SLOT(slotAnalyseTable()), pAactionCollection, "analyse_table" );
  
  (void) new KAction( i18n("&Vacuum table..."), 0, 0, this, SLOT(slotVacuumTable()), pAactionCollection, "vacuum_table" );
  
  (void) new KAction( i18n("Re&index table..."), 0, 0, this, SLOT(slotReindexTable()), pAactionCollection, "reindex_table" );
  
  (void) new KAction( i18n("Set c&luster on..."), 0, 0, this, SLOT(slotSetClusterOnTable()), pAactionCollection, "set_cluster_on_table" );
  
  (void) new KAction( i18n("Set &without cluster..."), 0, 0, this, SLOT(slotSetWithoutClusterTable()), pAactionCollection, "set_wo_cluster_table" );
  
  (void) new KAction( i18n("&Cluster table..."), 0, 0, this, SLOT(slotClusterTable()), pAactionCollection, "cluster_table" );
  
  (void) new KAction( i18n("Copy to &file..."), 0, 0, this, SLOT(slotCopyFromTable()), pAactionCollection, "copy_from_table" );
  
  (void) new KAction( i18n("Cop&y from file..."), 0, 0, this, SLOT(slotCopyToTable()), pAactionCollection, "copy_to_table" );
  
  (void) new KAction( i18n("Set &owner..."), 0, 0, this, SLOT(slotSetOwnerTable()), pAactionCollection, "set_owner_table" );
  
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesTable()), pAactionCollection, "grant_privileges_table" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesTable()), pAactionCollection, "revoke_privileges_table" );
  
  (void) new KAction( i18n("Set tables&pace..."), 0, 0, this, SLOT(slotSetTablespaceTable()), pAactionCollection, "set_tblspace_table" );
  
  (void) new KAction( i18n("Set without OIDs..."), 0, 0, this, SLOT(slotSetWithoutOIDsTable()), pAactionCollection, "set_wo_oids_table" );
    
    // TODO (void) new KAction(i18n("Edit table content..."), "data", 0, this, SLOT(slotEditTableContent()), pAactionCollection, "edit_table_content");
    
	//--- View related menu actions
	
	(void) new KAction( i18n("&Create view..."), "wizard", 0, this, SLOT(slotCreateView()), pAactionCollection, "create_view" );
	
	(void) new KAction( i18n("&Drop view..."), "editdelete", 0, this, SLOT(slotDropView()), pAactionCollection, "drop_view" );
	
	(void) new KAction( i18n("&Modify view..."), "edit", 0, this, SLOT(slotModifyView()), pAactionCollection, "modify_view" );
  
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesView()), pAactionCollection, "grant_privileges_view" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesView()), pAactionCollection, "revoke_privileges_view" );

  //--- Tablespaces related menu actions
  
  (void) new KAction( i18n("&Create tablespace..."), "wizard", 0, this, SLOT(slotCreateTablespace()), pAactionCollection, "create_tablespace" );
  
  (void) new KAction( i18n("&Drop tablespace..."), "editdelete", 0, this, SLOT(slotDropTablespace()), pAactionCollection, "drop_tablespace" );
  
  (void) new KAction( i18n("&Rename tablespace..."), "edittool", 0, this, SLOT(slotRenameTablespace()), pAactionCollection, "rename_tablespace" );
  
  (void) new KAction( i18n("Set &owner..."), 0, 0, this, SLOT(slotSetOwnerTablespace()), pAactionCollection, "set_owner_tablespace" );
  
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesTablespace()), pAactionCollection, "grant_privileges_tablespace" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesTablespace()), pAactionCollection, "revoke_privileges_tablespace" );
  
	//--- User related menu actions
	
	(void) new KAction( i18n("&Create user..."), "wizard", 0, this, SLOT(slotCreateUser()), pAactionCollection, "create_user" );
	
	(void) new KAction( i18n("&Drop user..."), "editdelete", 0, this, SLOT(slotDropUser()), pAactionCollection, "drop_user" );
	
	(void) new KAction( i18n("&Modify user..."), "edit", 0, this, SLOT(slotModifyUser()), pAactionCollection, "modify_user" );
	
	//--- Group related menu actions
	
	(void) new KAction( i18n("&Create group..."), "wizard", 0, this, SLOT(slotCreateGroup()), pAactionCollection, "create_group" );
	
	(void) new KAction( i18n("&Drop group..."), "editdelete", 0, this, SLOT(slotDropGroup()), pAactionCollection, "drop_group" );
	
	(void) new KAction( i18n("&Modify group..."), "edit", 0, this, SLOT(slotModifyGroup()), pAactionCollection, "modify_group" );
  
  //--- Language related menu actions
  
  (void) new KAction( i18n("&Create language..."), "wizard", 0, this, SLOT(slotCreateLanguage()), pAactionCollection, "create_language" );
  
  (void) new KAction( i18n("&Drop language..."), "editdelete", 0, this, SLOT(slotDropLanguage()), pAactionCollection, "drop_language" );
  
  (void) new KAction( i18n("&Rename language..."), "edittool", 0, this, SLOT(slotModifyLanguage()), pAactionCollection, "rename_language" );
  
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesLanguage()), pAactionCollection, "grant_privileges_language" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesLanguage()), pAactionCollection, "revoke_privileges_language" );
  
  //--- Domain related menu actions
  
  (void) new KAction( i18n("&Create domain..."), "wizard", 0, this, SLOT(slotCreateDomain()), pAactionCollection, "create_domain" );
  
  (void) new KAction( i18n("&Drop domain..."), "editdelete", 0, this, SLOT(slotDropDomain()), pAactionCollection, "drop_domain" );
  
  (void) new KAction( i18n("Set &NOT NULL..."), 0, 0, this, SLOT(slotSetDomainNull()), pAactionCollection, "set_domain_null" );
  (void) new KAction( i18n("Set d&efault..."), 0, 0, this, SLOT(slotSetDomainDefault()), pAactionCollection, "set_domain_default" );
  (void) new KAction( i18n("Dr&op default..."), 0, 0, this, SLOT(slotDropDomainDefault()), pAactionCollection, "drop_domain_default" );
  
  (void) new KAction( i18n("Set &owner..."), 0, 0, this, SLOT(slotSetOwnerDomain()), pAactionCollection, "set_owner_domain" );
  
  //--- Domain constraint related menu actions
  
  (void) new KAction( i18n("&Create constraint(s)..."), "wizard", 0, this, SLOT(slotCreateDomainConstraint()), pAactionCollection, "create_domain_constraint" );
  
  (void) new KAction( i18n("&Drop constraint..."), "editdelete", 0, this, SLOT(slotDropDomainConstraint()), pAactionCollection, "drop_domain_constraint" );
        
  //--- Function related menu actions
  
  (void) new KAction( i18n("&Create function..."), "wizard", 0, this, SLOT(slotCreateFunction()), pAactionCollection, "create_function" );
  
  (void) new KAction( i18n("&Drop function..."), "editdelete", 0, this, SLOT(slotDropFunction()), pAactionCollection, "drop_function" );
  
  (void) new KAction( i18n("&Rename function..."), "edittool", 0, this, SLOT(slotRenameFunction()), pAactionCollection, "rename_function" );

  (void) new KAction( i18n("&Modify function..."), "edit", 0, this, SLOT(slotModifyFunction()), pAactionCollection, "modify_function" );
      
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesFunction()), pAactionCollection, "grant_privileges_function" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesFunction()), pAactionCollection, "revoke_privileges_function" );
  
  //--- Sequence related menu actions
  
  (void) new KAction( i18n("&Create sequence..."), "wizard", 0, this, SLOT(slotCreateSequence()), pAactionCollection, "create_sequence" );
  
  (void) new KAction( i18n("&Drop sequence..."), "editdelete", 0, this, SLOT(slotDropSequence()), pAactionCollection, "drop_sequence" );
  
  (void) new KAction( i18n("&Modify sequence..."), "edit", 0, this, SLOT(slotModifySequence()), pAactionCollection, "modify_sequence" );
  
  (void) new KAction( i18n("Grant privileges..."), 0, 0, this, SLOT(slotGrantPrivilegesSequence()), pAactionCollection, "grant_privileges_sequence" );
  
  (void) new KAction( i18n("Revoke privileges..."), 0, 0, this, SLOT(slotRevokePrivilegesSequence()), pAactionCollection, "revoke_privileges_sequence" );
  
  //--- Column related menu actions
  
  (void) new KAction( i18n("&Create column(s)..."), "wizard", 0, this, SLOT(slotCreateColumn()), pAactionCollection, "create_columns" );
  
  (void) new KAction( i18n("&Drop column..."), "editdelete", 0, this, SLOT(slotDropColumn()), pAactionCollection, "drop_column" );
  
  (void) new KAction( i18n("&Rename column..."), "edittool", 0, this, SLOT(slotRenameColumn()), pAactionCollection, "rename_column" );

  (void) new KAction( i18n("Set &NOT NULL..."), 0, 0, this, SLOT(slotSetColumnNull()), pAactionCollection, "set_column_null" );
  (void) new KAction( i18n("Set d&efault..."), 0, 0, this, SLOT(slotSetColumnDefault()), pAactionCollection, "set_column_default" );
  (void) new KAction( i18n("Dr&op default..."), 0, 0, this, SLOT(slotDropColumnDefault()), pAactionCollection, "drop_column_default" );
  (void) new KAction( i18n("Change &type..."), 0, 0, this, SLOT(slotChangeColumnType()), pAactionCollection, "change_column_type" );
  (void) new KAction( i18n("Set &storage..."), 0, 0, this, SLOT(slotSetColumnStorage()), pAactionCollection, "set_column_storage" );
  (void) new KAction( i18n("Set st&atistics..."), 0, 0, this, SLOT(slotSetColumnStatistisc()), pAactionCollection, "set_column_stat" );
      
  //--- Constraint related menu actions
  
  (void) new KAction( i18n("&Create constraint(s)..."), "wizard", 0, this, SLOT(slotCreateConstraint()), pAactionCollection, "create_constraints" );
  
  (void) new KAction( i18n("&Drop constraint..."), "editdelete", 0, this, SLOT(slotDropConstraint()), pAactionCollection, "drop_constraint" );
  
	//--- Index related menu actions
  
  (void) new KAction( i18n("&Create index(es)..."), "wizard", 0, this, SLOT(slotCreateIndex()), pAactionCollection, "create_indexes" );
  
  (void) new KAction( i18n("&Drop index..."), "editdelete", 0, this, SLOT(slotDropIndex()), pAactionCollection, "drop_index" );
  
  (void) new KAction( i18n("&Rename index..."), "edittool", 0, this, SLOT(slotRenameIndex()), pAactionCollection, "rename_index" );
  
  (void) new KAction( i18n("Re&index..."), 0, 0, this, SLOT(slotReindexIndex()), pAactionCollection, "reindex_index" );
  
  (void) new KAction( i18n("Set &owner..."), 0, 0, this, SLOT(slotSetOwnerIndex()), pAactionCollection, "set_owner_index" );
  
  (void) new KAction( i18n("Set tables&pace..."), 0, 0, this, SLOT(slotSetTablespaceIndex()), pAactionCollection, "set_tblspace_index" );
  
  //--- Rule related menu actions
  
  (void) new KAction( i18n("&Create rule..."), "wizard", 0, this, SLOT(slotCreateRule()), pAactionCollection, "create_rule" );
  
  (void) new KAction( i18n("&Drop rule..."), "editdelete", 0, this, SLOT(slotDropRule()), pAactionCollection, "drop_rule" );
  
  //--- Trigger related menu actions
  
  (void) new KAction( i18n("&Create trigger..."), "wizard", 0, this, SLOT(slotCreateTrigger()), pAactionCollection, "create_trigger" );
  
  (void) new KAction( i18n("&Drop trigger..."), "editdelete", 0, this, SLOT(slotDropTrigger()), pAactionCollection, "drop_trigger" );
  
  (void) new KAction( i18n("&Enable trigger..."), 0, 0, this, SLOT(slotEnableTrigger()), pAactionCollection, "enable_trigger" );
  
  (void) new KAction( i18n("&Rename trigger..."), "edittool", 0, this, SLOT(slotRenameTrigger()), pAactionCollection, "rename_trigger" );
  
  	//--- Type related menu actions
  
  	(void) new KAction( i18n("&Create base type..."), "wizard", 0, this, SLOT(slotCreateBaseType()), pAactionCollection, "create_base_type" );
  
  	(void) new KAction( i18n("&Create composite type..."), "wizard", 0, this, SLOT(slotCreateCompositeType()), pAactionCollection, "create_composite_type" );
  
  	(void) new KAction( i18n("&Drop type..."), "editdelete", 0, this, SLOT(slotDropType()), pAactionCollection, "drop_type" );
  
  	(void) new KAction( i18n("Set &owner"), 0, 0, this, SLOT(slotSetOwnerType()), pAactionCollection, "set_owner_type" );
  
	//--- Common menu actions
	(void) new KAction( i18n("Set description..."), "comment", 0, this, SLOT(slotSetDescription()), pAactionCollection, "set_description" ); 
  
	//-----------------------------------------------------------------
	// path toolbar
  	//-----------------------------------------------------------------
	m_pActPathCombo = new KPoGreComboAction( i18n("Path Bar"), 0, this,                                    SLOT(slotPathSelected(const QString &)), pAactionCollection, "path_combo" );
	
	new KAction( i18n("Clear Path Bar"), BarIcon("locationbar_erase", 16), 0, this, SLOT(slotPathClear()), pAactionCollection, "path_clear" );
	
	QLabel *locationLabel = new ToolbarLabel( i18n("Path: ") );
	
	new KWidgetAction( locationLabel, i18n("Path: "), 0, this, 0, pAactionCollection, "path_label" );
	
	locationLabel->setBuddy( m_pActPathCombo->comboBox());
	
  
  //----------------------------------------------------------------------------
  	connect( view, SIGNAL(sigSelectionChanged(const KPGTreeItem::eNodeType, KPGTreeItem *, unsigned int, unsigned int)), this, SLOT(slotSelectionChanged(const KPGTreeItem::eNodeType, KPGTreeItem *, unsigned int, unsigned int)) );
	
  	connect( view, SIGNAL(sigEnableRunQueryAction(bool)), this, SLOT(slotEnableRunQueryAction(bool)) );
  
	connect( view, SIGNAL(sigEnableStopQueryAction(bool)), this, SLOT(slotEnableStopQueryAction(bool)) );
    
	connect( view, SIGNAL(sigEnableFileActions(bool, bool, bool)), this, SLOT(slotEnableFileActions(bool, bool, bool)) );
  
	connect( view, SIGNAL(sigEnableEditActions(bool, bool, bool, bool, bool, bool)), this, SLOT(slotEnableEditActions(bool, bool, bool, bool, bool, bool)) );
	
  	connect( view, SIGNAL(sigEnableDbFetchActions(bool, bool)), this, SLOT(slotEnableDbFetchActions(bool, bool)) );
    	
  
	// disable actions at startup
	m_pActFileSave->setEnabled(false);
	m_pActFileSaveAs->setEnabled(false);
	m_pActFilePrint->setEnabled(false);
	m_pActEditCut->setEnabled(false);
	m_pActEditCopy->setEnabled(false);
	m_pActEditPaste->setEnabled(false);
	
	// initial state
	m_pActDatabaseDisconnect->setEnabled(false);
	m_pActDatabaseWizard->setEnabled(false);
	
	m_pActFileExportResult->setEnabled(false);
	m_pActFileNew->setEnabled(true);
	m_pActFileOpen->setEnabled(true);
	m_pActFileOpenRecent->setEnabled(true);
	m_pActFileSave->setEnabled(false);
	m_pActFileSaveAs->setEnabled(false);
		
	m_pActEditFindNext->setEnabled(true);
	m_pActEditDeselect->setEnabled(false);
	
	m_pActViewNodeUp->setEnabled(false);
	m_pActViewNodeBack->setEnabled(false);
	m_pActViewNodeForward->setEnabled(false);
	
	m_pActDatabaseRunQuery->setEnabled(false);
	m_pActDatabaseStopQuery->setEnabled(false);
	m_pActDatabaseFetchNext->setEnabled(false);
	m_pActDatabaseFetchAll->setEnabled(false);
}


/////////////////////////////////////////////////////////////////////
//                     ACTION SLOTS
/////////////////////////////////////////////////////////////////////

void KPoGreController::slotFileNewWindow()
{
  slotStatusMsg(i18n("Opening a new application window..."));
	
  KPoGreView *new_window= new KPoGreView(KMdi::IDEAlMode);
  new_window->show();

  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotFileNew()
{
  	slotStatusMsg(i18n("Creating new document..."));
  	view->createSqlQueryResultChildView();
  	slotStatusMsg(i18n("Ready.")); 
}

void KPoGreController::slotFileOpen()
{
	slotStatusMsg(i18n("Opening file..."));
		
	KPGSqlQueryResultChildView* pChildView = view->getActiveSqlQueryResultChildView();
  	if(pChildView != 0)
  	{
  		if(pChildView->isModified())
		{
			slotFileSave();
		}
	
		KURL url=KFileDialog::getOpenURL(QString::null,	i18n("*.sql|SQL files"), view, i18n("Open File..."));
		if(!url.isEmpty())
		{
			pChildView->openDocument(url);
			//setCaption(url.fileName(), false);
			m_pActFileOpenRecent->addURL( url );
		}
	}
		
	slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotFileOpenRecent(const KURL& url)
{
  	slotStatusMsg(i18n("Opening file..."));
	
  	KPGSqlQueryResultChildView* pChildView = view->getActiveSqlQueryResultChildView();
  	if(pChildView != 0)
  	{
  		if(pChildView->isModified())
		{
			slotFileSave();
		}
		
		pChildView->openDocument(url);
		//setCaption(url.fileName(), false); 
	}

  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotFileSave()
{
  	slotStatusMsg(i18n("Saving file..."));
  	
  	KPGSqlQueryResultChildView* pChildView = view->getActiveSqlQueryResultChildView();
  	if(pChildView != 0)
  	{
		if(pChildView->URL().fileName() == i18n("Untitled"))
  			slotFileSaveAs();
		else
			pChildView->saveDocument(pChildView->URL());	
			
		m_pActFileSave->setEnabled(false); 
	}

  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotFileSaveAs()
{
	slotStatusMsg(i18n("Saving file with a new filename..."));

	KPGSqlQueryResultChildView* pChildView = view->getActiveSqlQueryResultChildView();
  	if(pChildView != 0)
  	{
		KURL url=KFileDialog::getSaveURL(QDir::currentDirPath(),
        	i18n("*.sql|SQL files"), view, i18n("Save as..."));
		if(!url.isEmpty())
		{
			pChildView->saveDocument(url);
			m_pActFileOpenRecent->addURL(url);
		}
	}

  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotFileClose()
{
  slotStatusMsg(i18n("Closing file..."));
  view->requestClose();
  slotStatusMsg(i18n("Ready."));  
}

void KPoGreController::slotFilePrint()
{
  slotStatusMsg(i18n("Printing..."));

  QPrinter printer;
  if (printer.setup(view))
  {
    view->print(&printer);
  }

  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotFileQuit()
{
  slotStatusMsg(i18n("Exiting..."));
  view->saveOptions();
  view->close();
}

// Undo last edit action in SQL query edit-widget
void KPoGreController::slotEditUndo()
{
	slotStatusMsg(i18n("Undo last edit action in SQL query"));
	view->editUndo();
	slotStatusMsg(i18n("Ready."));
}

// Redo last edit action in SQL query edit-widget
void KPoGreController::slotEditRedo()
{
	slotStatusMsg(i18n("Redo last edit action in SQL query"));
	view->editRedo();
  	slotStatusMsg(i18n("Ready."));
}		 

void KPoGreController::slotEditCut()
{
  slotStatusMsg(i18n("Cutting selection..."));
	view->editCut();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotEditCopy()
{
  slotStatusMsg(i18n("Copying selection to clipboard..."));
	view->editCopy();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotEditPaste()
{
  slotStatusMsg(i18n("Inserting clipboard contents..."));
	view->editPaste();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotEditFind()
{
	slotStatusMsg( i18n("Search in objects tree ...") );

	if ( ! m_pDlgSearch )
	{
		m_pDlgSearch = new KPGSearchDialog( view, "search dialog", true );
	}

	if( m_pDlgSearch->exec() == KPGSearchDialog::Accepted )
		slotEditFindNext();
	
	m_pActEditFindNext->setEnabled(true);

	slotStatusMsg( i18n("Ready.") );
}

void KPoGreController::slotEditFindNext()
{
	slotStatusMsg( i18n("Search in objects tree ...") );

	if ( ! m_pDlgSearch )
	{
		kdDebug() << "KPoGreController::slotEditFindNext implementation error - no search dialog" << endl;
		slotStatusMsg( i18n("Ready.") );
		return;
	}

	view->editFind(m_pDlgSearch->getSearchString(), m_pDlgSearch->getOIDs(), m_pDlgSearch->getInNames());

	slotStatusMsg( i18n("Ready.") );
}

void KPoGreController::slotViewNodeUp() 
{ 
	view->viewNodeUp(); 
}
    
void KPoGreController::slotViewNodeBack() 
{ 
	view->viewNodeBack(); 
}
    
void KPoGreController::slotViewNodeForward() 
{ 
	view->viewNodeForward(); 
}

void KPoGreController::slotViewToolBar()
{
  slotStatusMsg(i18n("Toggling toolbar..."));
  ///////////////////////////////////////////////////////////////////
  // turn Toolbar on or off
  if(!m_pActViewToolBar->isChecked())
  {
    view->toolBar("mainToolBar")->hide();
  }
  else
  {
    view->toolBar("mainToolBar")->show();
  }		

  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotViewStatusBar()
{
  slotStatusMsg(i18n("Toggle the statusbar..."));
  ///////////////////////////////////////////////////////////////////
  //turn Statusbar on or off
  if(!m_pActViewStatusBar->isChecked())
  {
    view->statusBar()->hide();
  }
  else
  {
    view->statusBar()->show();
  }

  slotStatusMsg(i18n("Ready."));
}

/** Connect to Database Server */
void KPoGreController::slotDatabaseConnect()
{
	slotStatusMsg(i18n("Connect to server ..."));
	view->setCursor(KCursor::waitCursor());
	
	view->databaseConnect();
	
	view->setCursor(KCursor::arrowCursor());
	slotStatusMsg(i18n("Ready."));
}

/** Disconnect Database */
void KPoGreController::slotDatabaseDisconnect()
{
	slotStatusMsg(i18n("Disconnect from server"));
	view->databaseDisconnect();
	slotStatusMsg(i18n("Ready."));
}

// Send SQL query to DB
void KPoGreController::slotDatabaseRunQuery()
{
  view->databaseRunQuery();
}

// Stop SQL operation
void KPoGreController::slotDatabaseStopQuery()
{
  view->databaseStopQuery();
}

// Fetch next X rows from large result
void KPoGreController::slotDatabaseFetchNext()
{
  view->databaseFetchNext();
}

// Fetch all rows from large result    
void KPoGreController::slotDatabaseFetchAll()
{
  view->databaseFetchAll();
}

void KPoGreController::slotDatabaseWizard()
{
  view->databaseWizard();
}


void KPoGreController::slotTableRefreshData()
{

}

void KPoGreController::slotTableFirstRow()
{

}

void KPoGreController::slotTablePreviousRow()
{

}

void KPoGreController::slotTableNextRow()
{

}

void KPoGreController::slotTableLastRow()
{

}

void KPoGreController::slotTableEditCell()
{

}


void KPoGreController::slotTableClearCell()
{

}


void KPoGreController::slotTableInsertRow()
{

}


void KPoGreController::slotTableDeleteRow()
{

}


void KPoGreController::slotTableCommitChanges()
{

}


void KPoGreController::slotTableCancelChanges()
{

}



/** Clear Input Area */
void KPoGreController::slotEditClearInputArea()
{
	slotStatusMsg(i18n("Clear Inputarea"));
	view->editClearInputArea();
	slotStatusMsg(i18n("Ready."));
}

/** Save query result to file */
void KPoGreController::slotExportResult()
{
	QString fileName = KFileDialog::getSaveFileName( QString(getenv("HOME") ), QString("*.csv"), view, QString("Export query-result as ...") );
	if( fileName != QString::null ) {			// OK, User made or selected a filename
		QFile* file = new QFile( fileName );
  		if( file->exists() )
			{ 
			  //is it already existing ?
  			QString error(fileName); 	
				error.append(i18n(" already exists!\n Do you wish to overwrite it ?"));
  	  	if (KMessageBox::questionYesNo(view, error, i18n("Overwrite File ?"))==KMessageBox::No) 
				{
  	  			slotExportResult();					//user does not want to overwrite ! -> jump out and recall
  	  			return;
  	  	}
  	  }
		
  	  	if ( ! file->open(IO_WriteOnly) ) {  // is he able to write to it ?
  	  		QString error(i18n("Error writing to "));
  	  		error.append(fileName);
  	  		error.append(" !");
  	  		KMessageBox::error( view, error, i18n("Error"));
  	  		return;
  	  	}
 		
  	  	else {   	  	                    //Yes, he is able to write !
  			QStringList list;
  			list << ";" << "|" << " ";
  			QString sep = QInputDialog::getItem( i18n("Field Separator ?"), i18n("Please choose a field separator !"), list  );
  			QTextStream* out = new QTextStream( file );
     		QTable* outputArea = view->getCurrentlySelectedTableResult();
        if(!outputArea)
          return;
          
			  int cols = outputArea->numCols();
     		int rows = outputArea->numRows();
     		for( int currentRow=0 ; currentRow<rows ; currentRow++ ){
     			for (int currentCol=0 ; currentCol<cols ; currentCol++ ){
     				*out << (outputArea->text( currentRow, currentCol )).stripWhiteSpace() << sep;
     			}
				*out << "\n";
			}
			file->flush();
			file->close();
		}
	}
}

// Called when user press Bookmarks Button
void KPoGreController::slotBookmarksButtonPressed()
{
  view->getBookmarksButton()->openPopup();
}


// Refresh selected item
void KPoGreController::slotRefresh()
{
	view->setCursor(KCursor::waitCursor());
	view->refresh();
	view->setCursor(KCursor::arrowCursor());
}

// Run Create Database Wizard 
void KPoGreController::slotCreateDatabase()
{
  slotStatusMsg(i18n("Create new database ..."));
	view->createDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run Drop Database Wizard 
void KPoGreController::slotDropDatabase()
{
  slotStatusMsg(i18n("Drop database ..."));
	view->dropDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run ANALYSE Wizard
void KPoGreController::slotAnalyseDatabase()
{
  slotStatusMsg(i18n("Analyse database ..."));
  view->analyseDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run REINDEX DATABASE Wizard
void KPoGreController::slotReindexDatabase()
{
  slotStatusMsg(i18n("Reindex database ..."));
  view->reindexDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DATABASE name OWNER TO new_owner Wizard
void KPoGreController::slotSetOwnerDatabase()
{
  slotStatusMsg(i18n("Set new database owner ..."));
  view->setOwnerDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for database
void KPoGreController::slotGrantPrivilegesDatabase()
{
  slotStatusMsg(i18n("Grant database privileges ..."));
  view->grantPrivilegesDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run REVOKE privileges Wizard for database
void KPoGreController::slotRevokePrivilegesDatabase()
{
  slotStatusMsg(i18n("Revoke database provileges ..."));
  view->revokePrivilegesDatabase();
  slotStatusMsg(i18n("Ready."));
}    

// Run DUMP DATABASE Wizard
void KPoGreController::slotDumpDatabase()
{
  slotStatusMsg(i18n("Dump database ..."));
  view->dumpDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run RESTORE DATABASE Wizard
void KPoGreController::slotRestoreDatabase()
{
  slotStatusMsg(i18n("Restore database ..."));
  view->restoreDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Close connection to database
void KPoGreController::slotDisconnectDatabase()
{
  slotStatusMsg(i18n("Disconnect from database ..."));
  view->disconnectDatabase();
  slotStatusMsg(i18n("Ready."));
}

// Run Create Schema Wizard 
void KPoGreController::slotCreateSchema()
{
  slotStatusMsg(i18n("Create new schema ..."));
	view->createSchema();
  slotStatusMsg(i18n("Ready."));
}

// Run Drop Schema Wizard 
void KPoGreController::slotDropSchema()
{
  slotStatusMsg(i18n("Drop schema ..."));
	view->dropSchema();
  slotStatusMsg(i18n("Ready."));
}

// Run Create or Replace Schema Wizard 
void KPoGreController::slotModifySchema()
{
  slotStatusMsg(i18n("Modify schema ..."));
	view->modifySchema();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER Schema OWNER TO new_owner Wizard 
void KPoGreController::slotSetOwnerSchema()
{
  slotStatusMsg(i18n("Set schema owner ..."));
  view->setOwnerSchema();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for schema
void KPoGreController::slotGrantPrivilegesSchema()
{
  slotStatusMsg(i18n("Grant schema privileges ..."));
  view->grantPrivilegesSchema();
  slotStatusMsg(i18n("Ready."));
}

// Run REVOKE privileges Wizard for schema
void KPoGreController::slotRevokePrivilegesSchema()
{
  slotStatusMsg(i18n("Revoke schema privileges ..."));
  view->revokePrivilegesSchema();
  slotStatusMsg(i18n("Ready."));
}    

// Run Create Table Wizard 
void KPoGreController::slotCreateTable()
{
  slotStatusMsg(i18n("Create table ..."));
	view->createTable();
  slotStatusMsg(i18n("Ready."));
}

// Run Drop Table Wizard 
void KPoGreController::slotDropTable()
{
  slotStatusMsg(i18n("Drop table ..."));
	view->dropTable();
  slotStatusMsg(i18n("Ready."));
}

// Run Alter Table Rename Wizard 
void KPoGreController::slotRenameTable()
{
  slotStatusMsg(i18n("Rename table ..."));
  view->renameTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotAnalyseTable()
{
  slotStatusMsg(i18n("Analyse table ..."));
  view->analyseTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotVacuumTable()
{
  slotStatusMsg(i18n("Vacuum table ..."));
  view->vacuumTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotReindexTable()
{
  slotStatusMsg(i18n("Reindex table ..."));
  view->reindexTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotSetClusterOnTable()
{
  slotStatusMsg(i18n("Set cluster on table ..."));
  view->setClusterOnTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotSetWithoutClusterTable()
{
  slotStatusMsg(i18n("Set table without cluster ..."));
  view->setWithoutClusterTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotClusterTable()
{
  slotStatusMsg(i18n("Cluster table ..."));
  view->clusterTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotCopyFromTable()
{
  slotStatusMsg(i18n("Copy from table ..."));
  view->copyFromTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotCopyToTable()
{
  slotStatusMsg(i18n("Copy to table ..."));
  view->copyToTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotSetOwnerTable()
{
  slotStatusMsg(i18n("Set table owner ..."));
  view->setOwnerTable();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for table
void KPoGreController::slotGrantPrivilegesTable()
{
  slotStatusMsg(i18n("Grant table privileges ..."));
  view->grantPrivilegesTable();
  slotStatusMsg(i18n("Ready."));
}

// Run REVOKE privileges Wizard for table
void KPoGreController::slotRevokePrivilegesTable()
{
  slotStatusMsg(i18n("Revoke table privileges..."));
  view->revokePrivilegesTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotSetTablespaceTable()
{
  slotStatusMsg(i18n("Choose tablespace for table ..."));
  view->setTablespaceTable();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotSetWithoutOIDsTable()
{
    slotStatusMsg(i18n("Set table to without OIDs ..."));
    view->setWithoutOIDsTable();
    slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotEditTableContent()
{
    slotStatusMsg(i18n("Edit table content ..."));
    view->editTableContent();
    slotStatusMsg(i18n("Ready."));
}

// Run Create View Wizard 
void KPoGreController::slotCreateView()
{
  slotStatusMsg(i18n("Create view ..."));
	view->createView();
  slotStatusMsg(i18n("Ready."));
}

// Run Drop View Wizard 
void KPoGreController::slotDropView()
{
  slotStatusMsg(i18n("Drop view ..."));
	view->dropView();
  slotStatusMsg(i18n("Ready."));
}

// Run Create or Replace View Wizard 
void KPoGreController::slotModifyView()
{
  slotStatusMsg(i18n("Modify view ..."));
	view->modifyView();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for view
void KPoGreController::slotGrantPrivilegesView()
{
  slotStatusMsg(i18n("Grant view privileges..."));
  view->grantPrivilegesView();
  slotStatusMsg(i18n("Ready."));
}

// Run REVOKE privileges Wizard for view
void KPoGreController::slotRevokePrivilegesView()
{
  slotStatusMsg(i18n("Revoke view privileges..."));
  view->revokePrivilegesView();
  slotStatusMsg(i18n("Ready."));
}

// Run Create Tablespace Wizard 
void KPoGreController::slotCreateTablespace()
{
  slotStatusMsg(i18n("Create tablespace ..."));
  view->createTablespace();
  slotStatusMsg(i18n("Ready."));
}

// Run Drpp Tablespace Wizard 
void KPoGreController::slotDropTablespace()
{
  slotStatusMsg(i18n("Drop tablespace ..."));
  view->dropTablespace();
  slotStatusMsg(i18n("Ready."));
}

// ALTER TABLESPACE name RENAME TO newname Wizard 
void KPoGreController::slotRenameTablespace()
{
  slotStatusMsg(i18n("Rename tablespace ..."));
  view->renameTablespace();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER TABLESPACE name OWNER TO newowner Wizard 
void KPoGreController::slotSetOwnerTablespace()
{
  slotStatusMsg(i18n("Modify tablespace ..."));
  view->setOwnerTablespace();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for tablespace
void KPoGreController::slotGrantPrivilegesTablespace()
{
  slotStatusMsg(i18n("Grant tablespace privileges..."));
  view->grantPrivilegesTablespace();
  slotStatusMsg(i18n("Ready."));
}

// Run REVOKE privileges Wizard for tablespace
void KPoGreController::slotRevokePrivilegesTablespace()
{
  slotStatusMsg(i18n("Revoke tablespace privileges..."));
  view->revokePrivilegesTablespace();
  slotStatusMsg(i18n("Ready."));
}   

// Run Create User Wizard 
void KPoGreController::slotCreateUser()
{
  slotStatusMsg(i18n("Create user ..."));
	view->createUser();
  slotStatusMsg(i18n("Ready."));
}

// Run Drpp User Wizard 
void KPoGreController::slotDropUser()
{
  slotStatusMsg(i18n("Drop user ..."));
	view->dropUser();
  slotStatusMsg(i18n("Ready."));
}

// Run Alter User Wizard 
void KPoGreController::slotModifyUser()
{
  slotStatusMsg(i18n("Modify user ..."));
	view->modifyUser();
  slotStatusMsg(i18n("Ready."));
}

// Run Create View Group 
void KPoGreController::slotCreateGroup()
{
  slotStatusMsg(i18n("Create group ..."));
	view->createGroup();
  slotStatusMsg(i18n("Ready."));
}

// Run Drpp Group Wizard 
void KPoGreController::slotDropGroup()
{
  slotStatusMsg(i18n("Drop group ..."));
	view->dropGroup();
  slotStatusMsg(i18n("Ready."));
}

// Run Alter Group Wizard 
void KPoGreController::slotModifyGroup()
{
  slotStatusMsg(i18n("Modify group ..."));
	view->modifyGroup();
  slotStatusMsg(i18n("Ready."));
}

// Run Create Language Wizard 
void KPoGreController::slotCreateLanguage()
{
  slotStatusMsg(i18n("Create language ..."));
  view->createLanguage();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Language Wizard 
void KPoGreController::slotDropLanguage()
{
  slotStatusMsg(i18n("Drop language ..."));
  view->dropLanguage();
  slotStatusMsg(i18n("Ready."));
}
    
// Run Alter Language Wizard 
void KPoGreController::slotModifyLanguage()
{
  slotStatusMsg(i18n("Modify language ..."));
  view->modifyLanguage();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for language
void KPoGreController::slotGrantPrivilegesLanguage()
{
  slotStatusMsg(i18n("Grant language privileges..."));
  view->grantPrivilegesLanguage();
  slotStatusMsg(i18n("Ready."));
}

// Run REVOKE privileges Wizard for language
void KPoGreController::slotRevokePrivilegesLanguage()
{
  slotStatusMsg(i18n("Revoke language privileges..."));
  view->revokePrivilegesLanguage();
  slotStatusMsg(i18n("Ready."));
}    

// Run CREATE DOMAIN Wizard 
void KPoGreController::slotCreateDomain()
{
  slotStatusMsg(i18n("Create domain ..."));
  view->createDomain();
  slotStatusMsg(i18n("Ready."));
}

// Run DROP DOMAIN Wizard 
void KPoGreController::slotDropDomain()
{
  slotStatusMsg(i18n("Drop domain ..."));
  view->dropDomain();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DOMAIN SET | DROP NOT NULL Wizard 
void KPoGreController::slotSetDomainNull()
{
  slotStatusMsg(i18n("Set domain NULL..."));
  view->setDomainNull();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DOMAIN SET DEFAULT expression Wizard 
void KPoGreController::slotSetDomainDefault()
{
  slotStatusMsg(i18n("Set domain default ..."));
  view->setDomainDefault();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DOMAIN DROP DEFAULT Wizard 
void KPoGreController::slotDropDomainDefault()
{
  slotStatusMsg(i18n("Drop domain default..."));
  view->dropDomainDefault();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DOMAIN name OWNER TO new_owner  Wizard 
void KPoGreController::slotSetOwnerDomain()
{
  slotStatusMsg(i18n("Set owner..."));
  view->setOwnerDomain();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DOMAIN name ADD domain_constraint Wizard 
void KPoGreController::slotCreateDomainConstraint()
{
  slotStatusMsg(i18n("Create domain constraint..."));
  view->createDomainConstraint();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER DOMAIN name DROP CONSTRAINT constraint_name Wizard 
void KPoGreController::slotDropDomainConstraint()
{
  slotStatusMsg(i18n("Drop domain constraint..."));
  view->dropDomainConstraint();
  slotStatusMsg(i18n("Ready."));
}    
    
// Run Create Function Wizard 
void KPoGreController::slotCreateFunction()
{
  slotStatusMsg(i18n("Create function ..."));
  view->createFunction();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Function Wizard 
void KPoGreController::slotDropFunction()
{
  slotStatusMsg(i18n("Drop function ..."));
  view->dropFunction();
  slotStatusMsg(i18n("Ready."));
}
   
// Run Alter Function Wizard 
void KPoGreController::slotRenameFunction()
{
  slotStatusMsg(i18n("Rename function ..."));
  view->renameFunction();
  slotStatusMsg(i18n("Ready."));
}
 
// Run Alter Function Wizard 
void KPoGreController::slotModifyFunction()
{
  slotStatusMsg(i18n("Modify function ..."));
  view->modifyFunction();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for function
void KPoGreController::slotGrantPrivilegesFunction()
{
  slotStatusMsg(i18n("Grant function privileges..."));
  view->grantPrivilegesFunction();
  slotStatusMsg(i18n("Ready."));
}    
    
// Run REVOKE privileges Wizard for function
void KPoGreController::slotRevokePrivilegesFunction()
{
  slotStatusMsg(i18n("Revoke function privileges..."));
  view->revokePrivilegesFunction();
  slotStatusMsg(i18n("Ready."));
}    

// Run Create Sequence Wizard 
void KPoGreController::slotCreateSequence()
{
  slotStatusMsg(i18n("Create sequence ..."));
  view->createSequence();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Sequence Wizard 
void KPoGreController::slotDropSequence()
{
  slotStatusMsg(i18n("Drop sequence ..."));
  view->dropSequence();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER Sequence Wizard 
void KPoGreController::slotModifySequence()
{
  slotStatusMsg(i18n("Modify sequence ..."));
  view->modifySequence();
  slotStatusMsg(i18n("Ready."));
}

// Run GRANT privileges Wizard for sequence
void KPoGreController::slotGrantPrivilegesSequence()
{
  slotStatusMsg(i18n("Grant sequence privileges..."));
  view->grantPrivilegesSequence();
  slotStatusMsg(i18n("Ready."));
}
    
// Run REVOKE privileges Wizard for sequence
void KPoGreController::slotRevokePrivilegesSequence()
{
  slotStatusMsg(i18n("Revoke sequence privileges..."));
  view->revokePrivilegesSequence();
  slotStatusMsg(i18n("Ready."));
}    

// Run ALTER table ADD Column Wizard
void KPoGreController::slotCreateColumn()
{
  slotStatusMsg(i18n("Create column ..."));
  view->createColumn();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table DROP Column Wizard
void KPoGreController::slotDropColumn()
{
  slotStatusMsg(i18n("Drop column ..."));
  view->dropColumn();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table Rename Column Wizard
void KPoGreController::slotRenameColumn()
{
  slotStatusMsg(i18n("Rename column ..."));
  view->renameColumn();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table SET/DROP Column NULL Wizard
void KPoGreController::slotSetColumnNull()
{
  slotStatusMsg(i18n("Set column NULL ..."));
  view->setColumnNull();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table ALTER Column SET DEFAULT Wizard
void KPoGreController::slotSetColumnDefault()
{
  slotStatusMsg(i18n("Set column default ..."));
  view->setColumnDefault();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER table ALTER Column DROP DEFAULT Wizard
void KPoGreController::slotDropColumnDefault()
{
  slotStatusMsg(i18n("Drop clumn default ..."));
  view->dropColumnDefault();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table ALTER Column TYPE Wizard
void KPoGreController::slotChangeColumnType()
{
  slotStatusMsg(i18n("Change column type ..."));
  view->changeColumnType();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table ALTER Column SET STORAGE { PLAIN | EXTERNAL | EXTENDED | MAIN } Wizard
void KPoGreController::slotSetColumnStorage()
{
  slotStatusMsg(i18n("Set column storage ..."));
  view->setColumnStorage();
  slotStatusMsg(i18n("Ready."));
}
    
// Run ALTER table ALTER Column SET STATISTICS Wizard
void KPoGreController::slotSetColumnStatistisc()
{
  slotStatusMsg(i18n("Set column statistics ..."));
  view->setColumnStatistisc();
  slotStatusMsg(i18n("Ready."));
}    

    
// Run Create Constraint Wizard 
void KPoGreController::slotCreateConstraint()
{
  slotStatusMsg(i18n("Create constraint ..."));
  view->createConstraint();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Constraint Wizard 
void KPoGreController::slotDropConstraint()
{
  slotStatusMsg(i18n("Drop constraint ..."));
  view->dropConstraint();
  slotStatusMsg(i18n("Ready."));
}

// Run Create Index Wizard 
void KPoGreController::slotCreateIndex()
{
  slotStatusMsg(i18n("Create index ..."));
  view->createIndex();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Index Wizard 
void KPoGreController::slotDropIndex()
{
  slotStatusMsg(i18n("Drop index ..."));
  view->dropIndex();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER Index RENAME Wizard 
void KPoGreController::slotRenameIndex()
{
  slotStatusMsg(i18n("Rename index ..."));
  view->renameIndex();
  slotStatusMsg(i18n("Ready."));
}

// Run REINDEX INDEX Wizard 
void KPoGreController::slotReindexIndex()
{
  slotStatusMsg(i18n("Reindex index ..."));
  view->reindexIndex();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER Index OWNER TO new_owner Wizard 
void KPoGreController::slotSetOwnerIndex()
{
  slotStatusMsg(i18n("Set index owner ..."));
  view->setOwnerIndex();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER Index SET TABLESPACE indexspace_name Wizard 
void KPoGreController::slotSetTablespaceIndex()
{
  slotStatusMsg(i18n("Rename tablespace for index ..."));
  view->setTablespaceIndex();
  slotStatusMsg(i18n("Ready."));
}

// Run Create Rule Wizard 
void KPoGreController::slotCreateRule()
{
  slotStatusMsg(i18n("Create rule ..."));
  view->createRule();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Rule Wizard 
void KPoGreController::slotDropRule()
{
  slotStatusMsg(i18n("Drop rule ..."));
  view->dropRule();
  slotStatusMsg(i18n("Ready."));
}

// Run Create Trigger Wizard 
void KPoGreController::slotCreateTrigger()
{
  slotStatusMsg(i18n("Create trigger ..."));
  view->createTrigger();
  slotStatusMsg(i18n("Ready."));
}
  
// Run Drop Trigger Wizard 
void KPoGreController::slotDropTrigger()
{
  slotStatusMsg(i18n("Drop trigger ..."));
  view->dropTrigger();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER table ENABLE/DISABLE trigger Wizard 
void KPoGreController::slotEnableTrigger()
{
  slotStatusMsg(i18n("Enable/disable trigger ..."));
  view->enableTrigger();
  slotStatusMsg(i18n("Ready."));
}

// Run ALTER Trigger RENAME Wizard 
void KPoGreController::slotRenameTrigger()
{
  slotStatusMsg(i18n("Rename trigger ..."));
  view->renameTrigger();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotCreateBaseType()
{
  slotStatusMsg(i18n("Create base type ..."));
  view->createBaseType();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotCreateCompositeType()
{
  slotStatusMsg(i18n("Create composite type ..."));
  view->createCompositeType();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotDropType()
{
  slotStatusMsg(i18n("Drop type ..."));
  view->dropType();
  slotStatusMsg(i18n("Ready."));
}

void KPoGreController::slotSetOwnerType()
{
  slotStatusMsg(i18n("Set type owner ..."));
  view->setOwnerType();
  slotStatusMsg(i18n("Ready."));
}  

void KPoGreController::slotSetDescription()
{
	slotStatusMsg("Set Description...");
	view->setDescription();
	slotStatusMsg("Ready.");
}

/////////////////////////////////////////////////////////////////////
//                           OTHER SLOTS
/////////////////////////////////////////////////////////////////////


void KPoGreController::slotEditDeselect() 
{ 
	view->editDeselect(); 
}

void KPoGreController::slotPathSelected( const QString & strPath )
{
	if(!view->selectItemByPath(strPath))
	{ // node not found, remove item from combo
		m_pActPathCombo->removeItem(strPath);
		m_pActPathCombo->slotClearEdit();
	}
}

void KPoGreController::slotPathClear()
{
	slotEditDeselect();
	m_pActPathCombo->slotFocusEdit();
}


void KPoGreController::slotSelectionChanged( const KPGTreeItem::eNodeType nodeType, KPGTreeItem * pItem, unsigned int iStackBackCount, unsigned int iStackForwardCount)
{
	bool bActDatabaseWizard = false;
	bool bActDatabaseDisconnect = false;
	bool bAddBookmarkMenu = false;
	
	if(!pItem)
	{
		m_pActViewNodeUp->setEnabled(false);
		m_pActEditDeselect->setEnabled(false);
	}
	else
	{
		m_pActViewNodeUp->setEnabled(true);
		m_pActEditDeselect->setEnabled(false);
	}
	
	m_pActViewNodeBack->setEnabled(iStackBackCount > 0);
	m_pActViewNodeForward->setEnabled(iStackForwardCount > 0);
	
	KActionCollection *pAactionCollection = view->actionCollection();
	
	switch(nodeType)
  	{
    	case KPGTreeItem::nodeUnselected:
        	m_pActDatabaseDisconnect->setEnabled(false);
        	break;

    	case KPGTreeItem::nodeServer:
      	{
        	bActDatabaseDisconnect = true;
        	bAddBookmarkMenu = true;
			bActDatabaseWizard = true;
				
        	KPGServer *pServer = static_cast <KPGServer *> (pItem);            
        	view->getBookmarksButton()->bookmarkHandler()->setNewBookmarkName(pServer->text(0));
        	view->getBookmarksButton()->bookmarkHandler()->setNewBookmarkUrl(pServer->url());
        
      	}
      	break;
				
		case KPGTreeItem::nodeFunction:
      	{
        	KPGFunction *pFunction = static_cast <KPGFunction *> (pItem);            
        
			KAction *pAct = pAactionCollection->action("modify_function");
			if(pAct)
			{
				pAct->setEnabled(pFunction->langName() != "c"); // Don't allow modify C function
			}
      	}
      	break;
      
    	case KPGTreeItem::nodeTablespace:
      	{
			KPGTablespace *pTablespace = static_cast <KPGTablespace *> (pItem);            
			
			KAction *pActModify = pAactionCollection->action("modify_tablespace");
			if(pActModify)
			{
			pActModify->setEnabled(!pTablespace->isSystemObject()); // Don't allow modify system tablespaces
			}
			
			KAction *pActDrop = pAactionCollection->action("drop_tablespace");
			if(pActDrop)
			{
			pActDrop->setEnabled(!pTablespace->isSystemObject()); // Don't allow drop system tablespaces
			}
      	}
      	break;
		      
		case KPGTreeItem::nodeDatabase:
      	{
			bActDatabaseWizard = true;
			
			KPGDatabase *pDatabase = static_cast <KPGDatabase *> (pItem);            
			
			KAction *pActModify = pAactionCollection->action("modify_database");
			if(pActModify)
			{
				pActModify->setEnabled(!pDatabase->isSystemObject() && !pDatabase->isTemplate()); // Don't allow modify system databases
			}
			
			KAction *pActDrop = pAactionCollection->action("drop_database");
			if(pActDrop)
			{
				pActDrop->setEnabled(!pDatabase->isSystemObject() && !pDatabase->isTemplate()); // Don't allow drop system databases
			}
      	}
     	break;  
    
    	case KPGTreeItem::nodeSchema:
      	{
			bActDatabaseWizard = true;
			
			KPGSchema *pSchema = static_cast <KPGSchema *> (pItem);            
			
			KAction *pActModify = pAactionCollection->action("rename_schema");
			if(pActModify)
			{
			pActModify->setEnabled(!pSchema->isSystemObject()); // Don't allow rename system schema
			}
			
			KAction *pActDrop = pAactionCollection->action("drop_schema");
			if(pActDrop)
			{
			pActDrop->setEnabled(!pSchema->isSystemObject()); // Don't allow drop system schema
			}
			
			KAction *pActSetOwner = pAactionCollection->action("set_owner_schema");
			if(pActSetOwner)
			{
			pActSetOwner->setEnabled(!pSchema->isSystemObject()); // Don't allow reowner system schema
			}
      	}
        break;
    
    	case KPGTreeItem::nodeTable:
      	{
			bActDatabaseWizard = true;
			
			KPGTable *pTable = static_cast <KPGTable *> (pItem);
			KPGServer *pServer = static_cast <KPGServer *> (pTable->getParentByType(KPGTreeItem::nodeServer));
			
			bool bVersion8 = false;
			if(pServer) bVersion8 = (pServer->versionMajor() >= 8);
			
			pAactionCollection->action("set_tblspace_table")->setEnabled(bVersion8);
      	}
      	break;     
            	
      
    	case KPGTreeItem::nodeTableColumn:
      	{
			KPGTableColumn *pColumn = static_cast <KPGTableColumn *> (pItem);
			KPGServer *pServer = static_cast <KPGServer *> (pColumn->getParentByType(KPGTreeItem::nodeServer));
			
			bool bEnableModifyAct = (pColumn->attNum() > 0); // don't allow modify system columns
			bool bVersion8 = false;
			
			if(pServer) bVersion8 = (pServer->versionMajor() >= 8);
			
			pAactionCollection->action("drop_column")->setEnabled(bEnableModifyAct);
			pAactionCollection->action("rename_column")->setEnabled(bEnableModifyAct);
			KAction *pActSetNull = pAactionCollection->action("set_column_null");
			pActSetNull->setEnabled(bEnableModifyAct);
			pAactionCollection->action("set_column_default")->setEnabled(bEnableModifyAct);
			pAactionCollection->action("drop_column_default")->setEnabled(bEnableModifyAct && pColumn->hasDefault());
			pAactionCollection->action("change_column_type")->setEnabled(bEnableModifyAct && bVersion8);
			pAactionCollection->action("set_column_storage")->setEnabled(bEnableModifyAct);
			pAactionCollection->action("set_column_stat")->setEnabled(bEnableModifyAct);
			
			if(!pColumn->isNotNull())
			pActSetNull->setText(i18n("Set &NOT NULL..."));
			else
			pActSetNull->setText(i18n("Drop &NOT NULL..."));
      	}
      	break;
      
		case KPGTreeItem::nodePrimaryKey:
		case KPGTreeItem::nodeIndex:
      	{
			KPGTableIndex *pTableIndex = static_cast <KPGTableIndex *> (pItem);
			KPGServer *pServer = static_cast <KPGServer *> (pTableIndex->getParentByType(KPGTreeItem::nodeServer));
			
			bool bVersion8 = false;
			if(pServer) bVersion8 = (pServer->versionMajor() >= 8);
			
			pAactionCollection->action("set_owner_index")->setEnabled(bVersion8);
			pAactionCollection->action("set_tblspace_index")->setEnabled(bVersion8);
      	}
      	break;  
    
    	case KPGTreeItem::nodeDomain:
      	{
			KPGDomain *pDomain = static_cast <KPGDomain *> (pItem);
			
			KAction *pActSetNull = pAactionCollection->action("set_domain_null");
			pAactionCollection->action("drop_domain_default")->setEnabled(pDomain->hasDefault());
			
			if(!pDomain->isNotNull())
				pActSetNull->setText(i18n("Set &NOT NULL..."));
			else
				pActSetNull->setText(i18n("Drop &NOT NULL..."));
      	}
      	break;
               
        case KPGTreeItem::nodeTrigger:
      	{
			KPGTrigger *pTrigger = static_cast <KPGTrigger *> (pItem);
			
			KAction *pActEnableTrigger = pAactionCollection->action("enable_trigger");
			
			if(!pTrigger->isEnabled())
				pActEnableTrigger->setText(i18n("&Enable trigger..."));
			else
				pActEnableTrigger->setText(i18n("&Disable trigger..."));
      	}
      	break;
               
      
		default:	
				break;
  }
	
	m_pActDatabaseDisconnect->setEnabled(bActDatabaseDisconnect);
	m_pActDatabaseWizard->setEnabled(bActDatabaseWizard);
	view->getBookmarksButton()->enableAddBookmarkMenu(bAddBookmarkMenu);
	
	// change path combo text
	if(pItem)
		{ 
			QString strPath(pItem->path());
			
			if((pItem->hasOid()))
			{
				KPGObject *pObject = static_cast <KPGObject *> (pItem);
				
				strPath.append(QString("[%1]").arg(pObject->oid()));
			}
		  m_pActPathCombo->insertItem(* pItem->pixmap(0), strPath);
		}
	else
		m_pActPathCombo->slotClear();
	
}

// Called, when document is modified. Enable Save button. */
void KPoGreController::slotDocumentModified()
{
	m_pActFileSave->setEnabled(true);
	//setCaption(doc->URL().fileName(), true);
}

// Enables/disables action Database -> Run SQL
void KPoGreController::slotEnableRunQueryAction(bool bEnable)
{
  	m_pActDatabaseRunQuery->setEnabled(bEnable);
}

// Enables/disables action Database -> Stop SQL
void KPoGreController::slotEnableStopQueryAction(bool bEnable)
{
  	m_pActDatabaseStopQuery->setEnabled(bEnable);
}

// Enables/disables File Open, Save and Export action
void KPoGreController::slotEnableFileActions(bool bEnableOpen, bool bEnableSave, bool bEnableExport)
{
	m_pActFileOpen->setEnabled(bEnableOpen);
  	m_pActFileOpenRecent->setEnabled(bEnableOpen);
  
	m_pActFileSave->setEnabled(bEnableSave);
  	m_pActFileSaveAs->setEnabled(bEnableSave);
  
	m_pActFileExportResult->setEnabled(bEnableExport);
}

// Enables/disables Edit actions
void KPoGreController::slotEnableEditActions(bool bEnableUndo, bool bEnableRedo, bool bEnableCutCopy, bool bEnablePaste, bool bEnableDeselect, bool bEnableClearInpArea)
{
	m_pActEditUndo->setEnabled(bEnableUndo);
	m_pActEditRedo->setEnabled(bEnableRedo);
	
	m_pActEditCut->setEnabled(bEnableCutCopy);
	m_pActEditCopy->setEnabled(bEnableCutCopy);
	m_pActEditPaste->setEnabled(bEnablePaste);
	
	m_pActEditDeselect->setEnabled(bEnableDeselect);
	m_pActEditClearInputArea->setEnabled(bEnableClearInpArea);
}

// Enables/disables actions Database -> Fetch Next, Fetch All
void KPoGreController::slotEnableDbFetchActions(bool bEnableFetchNext, bool bEnableFetchAll)
{
 	m_pActDatabaseFetchNext->setEnabled(bEnableFetchNext);
  	m_pActDatabaseFetchAll->setEnabled(bEnableFetchAll);
}
  
void KPoGreController::slotStatusMsg(const QString &text)
{
	///////////////////////////////////////////////////////////////////
  	// change status message permanently
  	view->statusBar()->clear();
  	view->statusBar()->changeItem(text, ID_STATUS_MSG);
}

